# rquote

`get_price`方法提供 A股/港股/美股/ETF基金/期货 日线历史数据获取

使用新浪/腾讯的id形式，如`sh000001`表示上证指数，`sz000001`表示深市000001股票`平安银行`，`sh510050`表示上证50指数ETF，`hk00700`表示港股腾讯。
期货代码需加`fu`前缀，如`fuAP2110`，美股需加对应交易所后缀，如`usBABA.N	`，`usC.N`	，`usAAPL.OQ`等

